#
# spec file for package ibus
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define gtk_binary_version %(pkg-config  --variable=gtk_binary_version gtk+-2.0)
%if 0%{?suse_version} == 1315
%define with_python3 0
%else
# temporary disable, 'coz ibus is not python3 ready
%define with_python3 0
%endif
%if 0%{?suse_version} > 1315
%define with_wayland 1
%else
%define with_wayland 0
%endif

Name:           ibus
Version:        1.5.13
Release:        4.1
Summary:        Intelligent Input Bus for Linux OS
License:        LGPL-2.1+
Group:          System/I18n/Chinese
Url:            https://github.com/ibus/
#Source:         https://github.com/ibus/ibus/releases/download/%{version}/%{name}-%{version}.tar.gz
Source:         %{name}-%{version}.tar.gz
Source2:        README.SUSE
Source3:        xim.ibus.suse.template
Source4:        xim.d-ibus-121
Source5:        kde.tar.gz
Source6:        kde-12.2.tar.gz
Source7:        macros.ibus
Source10:       ibus-autostart
Source11:       ibus-autostart.desktop
Source99:       baselibs.conf
# PATCH-FIX-OPENSUSE ibus-python-install-dir.patch ftake@geeko.jp
Patch0:         ibus-python-install-dir.patch
# PATFH-FIX-SUSE ibus-xim-fix-re-focus-after-lock.patch bnc#874869 tiwa@suse.de -- Fix lost XIM input after screenlock
Patch4:         ibus-xim-fix-re-focus-after-lock.patch
# PATCH-FIX-UPSTREAM marguerite@opensuse.org
# Ibus will use python3 only when variable PYTHON2 is empty.
# Thus ibus-setup and bindings are still bytecompiled with python2.
# Then python3 support is useless, so we force python3 when python3
# is enabled, and fix syntax errors in python-config.py
Patch5:         ibus-force-python3.patch
# PATCH-FIX-UPSTREAM marguerite@opensuse.org
# lower vala version
Patch6:         ibus-vala-0.18.patch
# PATCH-FIX-UPSTREAM marguerite@opensuse.org
Patch7:         ibus-python3-migration.patch
# PATCH-FIX-UPSTREAM ftake@geeko.jp
# Select an IM engine at the first login
Patch8:         im-engines-precede-xkb.patch
# PATCH-FIX-UPSTREAM ftake@geeko.jp
Patch9:         ibus-fix-check-abs-icon-path-support.patch
# PATCH-FIX-SLE hide-setup-menu.patch bnc#899259  qzhao@suse.com
# ibus-setup should not launch from main menu.
Patch10:        hide-setup-menu.patch
# PATCH-FIX-SLE setup-switch-im.patch bnc#899259  qzhao@suse.com
# switch to ibus when ibus not running.
Patch11:        setup-switch-im.patch
# PATCH-FIX-SLE ibus-disable-engines-preload-in-GNOME.patch bnc#1036729 qzhao@suse.com
# Disable ibus engines preload in GNOME for These works are handled by gnome-shell.
Patch12:        ibus-disable-engines-preload-in-GNOME.patch
BuildRequires:  dbus-1-glib-devel
BuildRequires:  dbus-1-python-devel >= 0.83.0
BuildRequires:  dconf-devel >= 0.7.5
BuildRequires:  fdupes
BuildRequires:  gconf2-devel
BuildRequires:  gettext-devel
BuildRequires:  glib2-devel >= 2.26.0
BuildRequires:  gobject-introspection-devel >= 0.9.6
BuildRequires:  gtk-doc >= 1.9
BuildRequires:  gtk2-devel
BuildRequires:  intltool
BuildRequires:  iso-codes-devel
BuildRequires:  libnotify-devel >= 0.7
BuildRequires:  libtool
# directory ownership {
BuildRequires:  oxygen-icon-theme
BuildRequires:  oxygen-icon-theme-scalable
BuildRequires:  x11-tools
# }
BuildRequires:  pkg-config
%if %{with_python3}
BuildRequires:  python3
BuildRequires:  python3-gobject2-devel
Requires:       python3-gobject2
%else
BuildRequires:  python
BuildRequires:  python-gobject-devel
Requires:       python-gobject
%endif
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(vapigen)
%if %{with_wayland}
BuildRequires:  pkgconfig(wayland-client) >= 1.2.0
%endif
BuildRequires:  pkgconfig(xkbcommon)
# It seems that old vala compiler cannot build with an incompatible
# return type error among two overriding functions with
# "GLib.Variant?" type
# 13.1 support should be dropped after the cause is confirmed
BuildRequires:  vala >= 0.26.0
Requires:       dbus-1-python
Requires:       dconf
Requires:       iso-codes
Requires:       libibus-1_0-5 = %{version}
# ibus-setup will require typelib(Gdk) typelib(GdkX11), typelib(Gtk)
# which are provided by two packages in openSUSE, so we limit their
# versions to 3.0 only.
Requires:       typelib-1_0-Gtk-3_0
Recommends:     %{name}-lang
# PATCH-FEATURE-SLE Add conflict with fcitx FATE #319095 qzhao@suse.com -- Solve the problem for the people update from SP0 to SP1
%if !0%{?is_opensuse}
Conflicts:      fcitx
%endif

#Fix cursor following problem in KDE4 for libreoffice.
%if 0%{?suse_version} != 1315
Supplements:    packageand(libreoffice:libreoffice-gnome)
%endif

Provides:       locale(ja;ko;zh)
Obsoletes:      ibus-gnome-shell
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
IBus means Intelligent Input Bus. It is a new input framework for Linux OS. It provides
full featured and user friendly input method user interface. It also may help
developers to develop input method easily.

%package -n libibus-1_0-5
Summary:        IBus libraries
Group:          System/I18n/Chinese
Obsoletes:      libibus-1_0-0

%description -n libibus-1_0-5
This package contains the libraries for IBus

%package -n typelib-1_0-IBus-1_0
Summary:        IBus libraries -- Introspection bindings
Group:          System/I18n/Chinese

%description -n typelib-1_0-IBus-1_0
This package contains the introspection bindings for the IBus library.

%package gtk
Summary:        IBus im module for gtk2
Group:          System/I18n/Chinese
Requires:       %{name} = %{version}
Supplements:    packageand(ibus:gtk2)
%{gtk2_immodule_requires}

%description gtk
This package contains ibus im module for gtk2

%package gtk3
Summary:        IBus im module for gtk3
Group:          System/I18n/Chinese
BuildRequires:  gtk3-devel
Requires:       %{name} = %{version}
Supplements:    packageand(ibus:gtk3)
%{gtk3_immodule_requires}

%description gtk3
This package contains ibus im module for gtk3

%if %{with_python3}
%package -n python3-ibus
Summary:        Python3 module for ibus
Group:          System/I18n/Chinese
Requires:       %{name} = %{version}
Requires:       python3
Obsoletes:      python-ibus

%description -n python3-ibus
This package contains python3 module for ibus

%else
%package -n python-ibus
Summary:        Python module for ibus
Group:          System/I18n/Chinese
Requires:       %{name} = %{version}
%py_requires

%description -n python-ibus
This package contains python module for ibus

%endif

%package branding-openSUSE-KDE
Summary:        openSUSE branding for KDE
Group:          System/GUI/KDE
Requires:       ibus = %{version}
Supplements:    packageand(ibus:branding-openSUSE-KDE)
Supplements:    packageand(ibus:kdelibs4)
Provides:       ibus-branding = %{version}
Conflicts:      otherproviders(ibus-branding)
%if 0%{?suse_version} >= 1140
BuildArch:      noarch
%endif

%description branding-openSUSE-KDE
openSUSE branding for KDE monochrome icons in systray.

%package devel
Summary:        Development tools for ibus
Group:          Development/Libraries/Other
Requires:       dbus-1-devel
Requires:       glib2-devel
Requires:       gtk-doc
Requires:       ibus = %{version}
Requires:       libibus-1_0-5 = %{version}
Requires:       typelib-1_0-IBus-1_0 = %{version}

%description devel
The ibus-devel package contains the header files and developer
docs for ibus.

%lang_package

%prep
%setup -q
%patch0 -p1

# hack to fix incompatibility of gtk-query-immodules-2.0 (bnc#845860)
%if 0%{?suse_version} < 1310
%patch6 -p1
sed -i \
    -e's@\(gtk-query-immodules-2.0-64\) --update-cache@\1 > <prefix>%{_sysconfdir}/gtk-2.0/gtk64.immodules@g' \
    -e's@\(gtk-query-immodules-2.0\) --update-cache@\1 > <prefix>%{_sysconfdir}/gtk-2.0/gtk.immodules@g' \
    %{SOURCE99}
%endif

%patch4 -p1

%if %{with_python3}
%patch5 -p1
%patch7 -p1
%endif

%patch8 -p1
%patch9 -p1

%if 0%{?suse_version} == 1315 && !0%{?is_opensuse}
%patch10 -p1
%patch11 -p1
%endif

cp -r %{SOURCE2} .
cp -r %{SOURCE3} .
cp -r %{SOURCE4} .
sed -i 1i"SYS_LIB=%{_lib}" xim.d-ibus-121
cp -r %{SOURCE10} .
cp -r %{SOURCE11} .
%if !0%{?is_opensuse}
%patch12 -p1
%endif

%build
autoreconf -fi
intltoolize -f
%configure --disable-static \
           --enable-gtk3 \
           --enable-vala \
%if %{with_python3}
	   --with-python=python3 \
%endif
           --enable-python-library \
           --enable-introspection \
           --disable-gconf \
           --enable-dconf \
           --enable-gtk-doc \
%if %{with_wayland}
           --enable-wayland \
%endif
%if 0%{?suse_version} < 1315
           --disable-appindicator \
%endif
           --enable-surrounding-text \
           --enable-appindicator_engine_icon \
           --libexecdir=%{_libdir}/ibus

make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install -j1

# autostart
mkdir -p %{buildroot}%{_sysconfdir}/X11/xim.d/
install -m 644 xim.d-ibus-121 %{buildroot}%{_sysconfdir}/X11/xim.d/ibus
mkdir -p %{buildroot}%{_bindir}
install -c -m 0755 ibus-autostart %{buildroot}%{_bindir}/ibus-autostart
mkdir -p %{buildroot}%{_sysconfdir}/xdg/autostart
install -c -m 0644 ibus-autostart.desktop %{buildroot}%{_sysconfdir}/xdg/autostart/ibus-autostart.desktop

sed -i 1i"SYS_LIB=%{_lib}" %{buildroot}%{_sysconfdir}/X11/xim.d/ibus

PRIORITY=40
pushd %{buildroot}%{_sysconfdir}/X11/xim.d/
    for lang in am ar as bn el fa gu he hi hr ja ka kk kn ko lo ml my \
                pa ru sk vi zh_TW zh_CN zh_HK zh_SG \
                de fr it es nl cs pl da nn nb fi en sv
    do
        mkdir $lang
        pushd $lang
            ln -s ../ibus $PRIORITY-ibus
        popd
    done
popd

# remove static libs
find %{buildroot}/%{_libdir} -name "*.la" -type f -delete -print

mkdir -p %{buildroot}%{_datadir}/pixmaps
ln -sf %{_datadir}/icons/hicolor/48x48/apps/ibus-keyboard.png \
  %{buildroot}%{_datadir}/pixmaps/ibus-keyboard.png

# touch for %%ghost
touch %{buildroot}/%{_sysconfdir}/dconf/db/ibus

# fix kde monochrome icons
%if 0%{?suse_version} >= 1230
cp -r %{SOURCE5} ./
%else
cp -r %{SOURCE6} ./
mv kde-12.2.tar.gz kde.tar.gz
%endif
tar -xzf kde.tar.gz
pushd kde
for i in 16 22 24 32 48 ; do
	mkdir -p %{buildroot}%{_datadir}/icons/oxygen/${i}x${i}/apps/
	cp -r ibus-keyboard.${i}x${i}.png %{buildroot}%{_datadir}/icons/oxygen/${i}x${i}/apps/ibus-keyboard.png
done
mkdir -p %{buildroot}%{_datadir}/icons/oxygen/scalable/apps/
cp -r ibus-keyboard.svgz %{buildroot}%{_datadir}/icons/oxygen/scalable/apps/
popd

# install macros
mkdir -p %{buildroot}%{_sysconfdir}/rpm
install -m 644 %{SOURCE7} %{buildroot}%{_sysconfdir}/rpm

%suse_update_desktop_file -r %{name}-setup Settings DesktopSettings X-SuSE-Core-System

%fdupes %{buildroot}

%find_lang ibus10 %{?no_lang_C}

%post
%{glib2_gsettings_schema_post}

%posttrans
dconf update

%postun
%{glib2_gsettings_schema_postun}
dconf update

%post gtk
%{gtk2_immodule_post}

%postun gtk
%{gtk2_immodule_postun}

%post -n libibus-1_0-5 -p /sbin/ldconfig

%postun -n libibus-1_0-5 -p /sbin/ldconfig

%post gtk3
%{gtk3_immodule_post}

%postun gtk3
%{gtk3_immodule_postun}

%files
%defattr(-,root,root)
%doc AUTHORS COPYING README README.SUSE xim.ibus.suse.template
%config %{_sysconfdir}/rpm/macros.ibus
%config %{_sysconfdir}/X11/xim.d/*
%{_bindir}/ibus
%{_bindir}/ibus-autostart
%{_bindir}/ibus-daemon
%{_bindir}/ibus-setup
%{_datadir}/ibus/
%{_datadir}/applications/ibus-setup.desktop
%{_datadir}/GConf/gsettings/ibus.convert
%{_datadir}/glib-2.0/schemas/org.freedesktop.ibus.gschema.xml
%{_datadir}/icons/hicolor/*/apps/ibus*.*
%{_datadir}/pixmaps/ibus-keyboard.png
%{_libdir}/ibus
%{_datadir}/bash-completion/completions/ibus.bash
# This file is generated by dconf update
%ghost %{_sysconfdir}/dconf/db/ibus
%dir %{_sysconfdir}/dconf/db/ibus.d
# This file is not a config file. Users may not modify it.
%{_sysconfdir}/dconf/db/ibus.d/00-upstream-settings
%{_sysconfdir}/dconf/profile/ibus
%{_sysconfdir}/xdg/autostart/ibus-autostart.desktop
%{_mandir}/man1/ibus.1.gz
%{_mandir}/man1/ibus-daemon.1.gz
%{_mandir}/man1/ibus-setup.1.gz

%files lang -f ibus10.lang
%defattr(-,root,root)

%files -n libibus-1_0-5
%defattr(-,root,root)
%{_libdir}/libibus-1.0.so.*

%files -n typelib-1_0-IBus-1_0
%defattr(-,root,root)
%{_libdir}/girepository-1.0/IBus-1.0.typelib

%files gtk
%defattr(-,root,root)
%{_libdir}/gtk-2.0/%{gtk_binary_version}/immodules/im-ibus.so

%files gtk3
%defattr(-,root,root)
%{_libdir}/gtk-3.0/3.0.0/immodules/im-ibus.so

%if %{with_python3}
%files -n python3-ibus
%defattr(-,root,root)
%{python3_sitearch}/ibus

%else

%files -n python-ibus
%defattr(-,root,root)
%{python_sitearch}/ibus
%{python_sitearch}/gi/overrides/*

%endif

%files devel
%defattr(-,root,root)
%{_libdir}/libibus-1.0.so
%{_includedir}/ibus-1.0
%{_datadir}/gtk-doc/html/ibus
%{_libdir}/pkgconfig/ibus-1.0.pc
%{_datadir}/gir-1.0/IBus-1.0.gir
%{_datadir}/vala/vapi/ibus-1.0.deps
%{_datadir}/vala/vapi/ibus-1.0.vapi

%files branding-openSUSE-KDE
%defattr(-,root,root)
%dir %{_datadir}/icons/oxygen/*
%dir %{_datadir}/icons/oxygen/*/apps
%{_datadir}/icons/oxygen/*/apps/ibus-keyboard.*

%changelog
* Sat May 27 2017 qzhao@suse.com
- Update ibus.spec: copy auto-start files to SOURCE directory
  to enable modifications before compile.
- Add ibus-disable-engines-preload-in-GNOME.patch: Disable load
  preload-engines actions in SLE, which is unnecessary for mono IMF
  in SLE and may cause CJK user login failed (bsc#1036729).
* Mon Apr 18 2016 ftake@geeko.jp
- Upstream update to 1.5.13
  * Add SetCursorLocationRelative D-Bus method
- Upstream update to 1.5.12
  * Fix ibus-daemon does not update user cache
  * Fix lookup window on a secondary monitor cannot get its correct
    size
  * Fix default position of property panel under multi monitor
    environments
  * Change language code from ISO 939-2 to ISO 639-1
  * Fix minor bugs
* Mon Apr 18 2016 ftake@geeko.jp
- Drop show-input-mode-icon.patch
  * this feature has been reimplemented in another approach
* Wed Apr 13 2016 hrvoje.senjan@gmail.com
- Own all oxygen icon subdirs, starting with KF 5.21.0, oxygen is
  no longer installed to the same location
* Wed Mar 23 2016 fcrozat@suse.com
- Do not apply SLE patches on openSUSE 13.2.
- Drop ibus-adapt-new-vala.patch, not needed after all with vala
  0.32.
* Sun Feb 28 2016 qzhao@suse.com
- Add ibus-adapt-new-vala.patch: Fix ibus compile error under
  new vala compiler, for SLE Desktop 12 SP2. This patch is only
  for SLED.
* Sun Feb 28 2016 qzhao@suse.com
- Add conflict to fcitx to fulfill FATE#319095
  deprecate fcitx chinese input method in favor of ibus
  (dummy bsc#933411). This modification is only for SLED.
* Sun Feb 28 2016 sbrabec@suse.com
- Add support for translation-update-upstream (dummy bsc#933411).
* Sun Feb 28 2016 qzhao@suse.com
- Add setup-switch-im.patch. Switch to ibus when ibus not
  running.(bnc#899259). This patch is only for SLED.
* Sun Feb 28 2016 qzhao@suse.com
- Add hide-setup-menu.patch
  Make ibus-setup launch from indicator field.(bnc#899259)
  Remove ibus-setup.desktop from main menu. This patch is only
  for SLED.
* Wed Feb 24 2016 tiwai@suse.de
- Fix the invocation of ibus service for KDE, etc (boo#968486):
  for DEs known to support autostart (KDE, XFCE and LXCE), ibus is
  now started via XDG autostart for avoiding the race.  This should
  fix the missing ibus service.  For other DEs, ibus is still
  started in xim script, but with a slight (two seconds) delay for
  avoiding the race, too.
  Along with the change, INPUT_METHOD environment variable is set
  explicitly in xim script at startup; this is referred in XDG
  autostart so that it won't be executed when other IM is chosen.
  Last but not least, the explicit dbus-launch invocation is dropped,
  as it's known to conflict with DE's own startup of dbus
* Mon Aug 10 2015 ftake@geeko.jp
- Update to 1.5.11
  * Add Swedish svdvorak layout support
  * Improve UI of ibus-setup
  * Show property panel at bottom right under KDE
  * Enable absolute path to icon for appindicator
  * Support showing language icon and a property for Plasma 5
  * Use GTK 3 for xim
  * Load locale compose files dynamically
  * Enable sync mode for xim
  * Support vertical writing
- Enable appindicator status icon for SLE12 and Leap 42.1
  (boo#939506)
- Remove a bashism from /etc/xim.d/ibus (boo#941052)
- Requires newer vala compiler
  * Cannot compile with an incompatible return type error
  * 13.1 support should be dropped after the cause is confirmed
- Drop appindicator-absolute-icon-path.patch
  * Merged by upstream
- Add ibus-fix-check-abs-icon-path-support.patch
  * Allows to force absolute path regardless of Qt version
- Refresh show-input-mode-icon.patch
  * Do not scale up icon for the new appindicator status icon
* Sat Mar 28 2015 ftake@geeko.jp
- Fix boo#924696: settings of ibus engines are not saved
  * Remove inappropriate %%ghost from the dconf files
- Disable appindicator for 13.1
  * It requires Qt 5.3 to show icons specified by absolute path
* Thu Mar 12 2015 ftake@geeko.jp
- Update to 1.5.10
  * Fix losing focus in/out on Google Chrome
  * Fix SEGV of ibus-ui-gtk3 caused by inappropriate 'preload-engines'
  * ibus-setup tries C locale to support environment without
    en_US.UTF-8
  * Remove "Release" modifier key from ibus-setup
  * Show language rather than layout for xkb panel icon
  * Track window property offsets correctly
  * Add IBus panel icon for Plasma 5 desktop
  * Minor bug fixes
- Update show-input-mode-icon.patch
  * Support the new panel icon
- Add appindicator-absolute-icon-path.patch
  * Show icons installed out of theme directories
* Sat Jan 24 2015 antoine.belvire@laposte.net
- modify xim.d-ibus-121: remove obsolete 'PATH=$OLD_PATH' which
  causes loss of the PATH variable when sourced
* Sat Nov 22 2014 coolo@suse.com
- disable parallel build for install - not much gain and makes it
  less reliable
* Tue Oct 14 2014 hillwood@linuxfans.org
- Update to 1.5.9
  * Enable preedit color on external preedit window with x11 applications.
  * Do not fail ibus-setup when en_US.UTF-8 is not installed.
  * Fix compose keys in French layout bepo variant.
* Mon Oct 13 2014 gber@opensuse.org
- use desktop file categories Settings;DesktopSettings instead of
  System
* Wed Oct  8 2014 ftake@geeko.jp
- Add im-engines-precede-xkb.patch
  * allow users to use an IM engine without any operation
- Update the launch script
  * remove the obsolete part for SKIM (bnc#860486)
  * do not set OOO_FORCE_DESKTOP=gnome
    if libreoffice-gnome is not installed (bnc#899045)
* Mon Sep  8 2014 fcrozat@suse.com
- Do not suggest to install ibus when installing
  libreoffice/libreoffice-gnome on SLE12.
* Fri Sep  5 2014 i@marguerite.su
- properly disable python3 builds:
  * ibus itself isn't python3 ready, its python module is totally
    not usable under python3.
- move some Obsoletes to the correct sub-package.
* Sun Aug 31 2014 hillwood@linuxfans.org
- Fix bnc#893271. Keep python-ibus.
* Sat Aug 30 2014 i@marguerite.su
- Add patch: ibus-python3-migration.patch
  * I didn't do the hard "port", just simple 2to3 tasks.
  * it'll remove "blockage" or python3-ibus is totally unusable.
* Tue Aug 26 2014 fcrozat@suse.com
- Do not only requires typelib-1_0-Gtk-3_0 when building with
  python3.
* Fri Aug 22 2014 fcrozat@suse.com
- Update ibus xim script to properly detect GNOME 3.12+ and to use
  ibus default configuration on first startup of GNOME (bnc#862589
  internal), with help from Takashi Iwai.
* Mon Aug 11 2014 fcrozat@suse.com
- Fix default category for ibus-setup.desktop.
* Tue Aug  5 2014 fcrozat@suse.com
- Do not build with python3 or wayland on SLE12.
- Fix file list when building with python2.
* Thu Jul 31 2014 ftake@geeko.jp
- remove patches merged by upstream
  * add-libgnomekbd-and-load-preload-engines.patch
  * reload-preload-engines-until-users-customize-the-list.patch
- obsoletes python-ibus when packaged for Python 3
* Sun Jul 27 2014 i@marguerite.su
- fix hillwood's timestamp in changelog
- add two more macros to macros.ibus
* Sat Jul 26 2014 i@marguerite.su
- update version 1.5.8
  * Set max-width-chars property in ibus-setup wrapped GtkLabel
  * Add German (nodeadkeys) keymap in simple.xml
  * Delete Korean keymap
  * Let ibus-ui-gtk3 not to show zero-lenght preedit text
  * Fix many memory leaks provided by Christophe Fergeau
  * Add Polish (qwertz) keymap in simple.xml
  * Fix escape key with Ctrl+Shift+U ISO
  * Update ibuscomposetable.h for pt-br
  * Set up ibus engines when users log into the session for the first time
  * Do not sort ibus engines when they are saved by ibus-setup
  * Update IBusKeymap jp
  * Run xmodmap after run setxkbmap -l layout
  * Add ibus reset-config and read-config sub-commands
  * Fix ibus-setup SEGV in enginetreeview.py
  * Fix deprecated warnings with python3-gobject 3.13.3
  * Export the 'IBUS_SETUP_XID' environment variable for each engine setup
  * Fix deprecated gtk3 GtkMisc, GtkAlignment and vala Gdk.X11Display
  * Enhance UI to add engines on ibus-setup
- mask add-libgnomekbd-and-load-preload-engines.patch and
  reload-preload-engines-until-users-customize-the-list.patch
  * upstream may have fixed these issues as these patches are issued
    on May 7th.
- use python3 to build ibus, as hillwood switched ibus-table to python3
  * add ibus-force-python3.patch, because ibus will use python3 to build
    ibus-setup and bindings only when PYTHON2 variable is empty. And fix
    'print sysconfig.PREFIX' syntax errors in python-config.py.
- add ibus-vala-0.18.patch to fix build for openSUSE 12.3
* Sat Jul 26 2014 i@marguerite.su
- clean specfile with service and spec-cleaner
  * don't use vague wildcards aggresively in %%%%files section
- add macros.ibus to ease packaging
* Sat Jul 26 2014 hillwood@linuxfans.org
- Enable wayland support
* Thu Jun  5 2014 ftake@geeko.jp
- Update to 1.5.7
  * Add Czech (qwerty) keymap
  * Enables to get current input context from panels
  * Fix leakage in ibus_get_local_machine_id()
  * Do not show Property Panel by default
  * Focus-in events do not move Property Panel
    if the panel is configured to be always shown
* Tue May 20 2014 tiwai@suse.de
- Fix the lost XIM input after GNOME screen lock (bnc#874969):
  ibus-xim-fix-re-focus-after-lock.patch
* Wed May 14 2014 cxiong@suse.com
- Let GNOME 3 handles ibus startup&setup. (bnc#873016)
  * Changed xim.d-ibus-121.
  * Reformatting the latter part of the xim.d-ibus-121.
* Mon Mar 17 2014 ftake@geeko.jp
- Update to 1.5.6
  * Support python3 (not enabled for this package)
  * Fix Property Panel is sometimes not shown when the focus is changed
  * Let Property Panel not to follow cursor if it is always shown
  * Fix a build error of Gdk.EventKey with vala 0.23.2
  * Use XKB layout strings instead of the ibus-keyboard icon on the panel
- Update reload-preload-engines-until-users-customize-the-list.patch
- Update ibus-python-install-dir.patch
  * modify Python 2 path in configure.ac instead of Makefile.am
- Refresh add-libgnomekbd-and-load-preload-engines.patch
* Mon Mar 17 2014 fcrozat@suse.com
- Clean-up dependencies: add librsvg2 (needed by ibus), dropped
  notification-daemon, python-gtk, python-notify (not needed with
  switch to pygobject), typelib-1_0-Gtk-2_0, typelib-1_0-Gtk-3_0
  (no need to hardcode, bnc#868657)
* Fri Feb 14 2014 tiwai@suse.de
- Fix *-32bit post and postun calls for gtk-query-immodules-2 on
  openSUSE 13.1 and later (bnc#845860)
* Mon Feb 10 2014 fcrozat@suse.com
- Do not requires gobject-introspection, it is not needed to run
  ibus, python-gobject is enough.
* Mon Jan 27 2014 ftake@geeko.jp
- Update to 1.5.5
  * Add Property Panel showing IME properties
  * Add French layout variant “oss” and the Slovak qwerty layout
  * Support customizing the look-up-table orientation of ibus-ui-gtk3.
  * Update en-us compose table and add locale tables for xkb engines
  * Delete the up/down buttons and the message about them on ibus-setup.
  * Fix candidate panel placed out of screen
  * Remove -Werror in autogen.sh
- Remove Always-save-the-content-type-cache-for-gnome-shell-p.patch
  * mergerd by upstream
- Refresh show-input-mode-icon.patch
- Update reload-preload-engines-until-users-customize-the-list.patch
  and add-libgnomekbd-and-load-preload-engines.patch
  * fix ibus-ui-gtk3 crashes if layout is en_intl (bnc#859354)
* Mon Nov 25 2013 hillwood@linuxfans.org
- Better way to fix cursor following problem (on_the_spot bug)
  under libreoffice-kde4 (bnc#851982).
* Sat Nov 16 2013 jengelh@inai.de
- Add missing python-gobject dependency (bnc#850792)
* Thu Oct 31 2013 tiwai@suse.de
- Always-save-the-content-type-cache-for-gnome-shell-p.patch:
  This is an additional fix patch for ibus to avoid the wrong
  IBus.InputPurpose.PASSWORD advertisement, which leads to the
  password text appearance on GNOME3 (bnc#847718)
* Thu Oct 17 2013 i@marguerite.su
- add a branding-openSUSE-KDE subpackage.
  * provides kde monochrome icons for 13.1 default KDE theme.
- port fix for bnc#820218 here
  * ibus qt tray icon is not in keeping with KDE monochrome icon look.
* Mon Oct 14 2013 hillwood@linuxfans.org
- Obsoletes libibus-1_0-0
* Thu Oct 10 2013 ftake@geeko.jp
- Update show-input-mode-icon.patch
  * fix ibus-ui-gtk3 hangs up
  * fix icons are cropped on KDE
* Sun Oct  6 2013 ftake@geeko.jp
- Update to 1.5.4
  * Add "address" command to command line interface
  * Support content-type of input context
  * Replace ibus-config with gsettings
  * Support using a different IM engine state for each window
  * Support show-icon-on-systray in ibus-ui-gtk3
  * Fix no output when ibus-daemon is runnin on another display
  * Update translations and fix build errors
- Add show-input-mode-icon.patch
  * workaround for the current input mode is not shown on DEs
    other than GNOME
- Rename and refresh patches
  * add-libgnomekbd-and-load-preload-engines.patch
  * reload-preload-engines-until-users-customize-the-list.patch
- Fix ibus-lang is not installed
- Fix warning by "touch /etc/dconf/db/ibus" for 12.3 and later
* Fri Sep 13 2013 ftake@geeko.jp
- Fix dconf schema was not updated for automatic configuration
- Fix 00-upstream-settings was wrongly marked as %%config
- Fix /etc/dconf/db/ibus was not owned by package
- Add %%if %%endif for automatic configuration
* Thu Sep 12 2013 ftake@geeko.jp
- Add patches to configure ibus automatically according to the
  current environment at the first login
  * Add reload-preload-engines-until-users-customize-the-list-95fd937e.patch
  * Add add-libgnomekbd-and-load-preload-engines-69171c9c.patch
- Enable the surrounding text feature
* Tue Jul 30 2013 ftake@geeko.jp
- Update to 1.5.3
  * Add embed_preedit_text
  * Disable IM on lock screen
  * Change defalut triggers key to <Super>space
  * Add man files
  * Delete ibus.desktop
  * Add Norwegian keyboard
  * Update UI, improve performance, fix build problems
* Tue Jul  9 2013 hillwood@linuxfans.org
- Fix cursor following problem in KDE4 for libreoffice
* Thu Jul  4 2013 ftake@geeko.jp
- Merge branches on M17N:Devel and home:dimstar:branches:GNOME:Factory
  * Merge changelog and spec written by dimstar@opensuse.org
- Update to 1.5.2 by hillwood@linuxfans.org
  * Implement use-system-keyboard-layout
  * Fix crash of ibus-setup
- Update to 1.5.1 by hillwood@linuxfans.org
  * Add fr(bepo) XKB engine
  * Fix crash
- Update to 1.5.0 by douglarek@outlook.com
  * Renew IM-switch UI, logic, and shortcut customization
  * Integrate XKB keyboard layouts into IME. Now ibus can manage both
    IME and XKB layouts seamlessly
  * Improve ibus performance by replace some python components with
    vala implementations
  * Improve gobject-introspection support
  * Improve vala language support
  * New functions to restrict config signal: ibus_config_watch/unwatch
  * Remove gnome-icon-theme-legacy dependency.
  * Add version property in IBusEngineDesc.
  * Add IBusProperty.symbol for the short label.
  * Support dconf 0.13.4
  * Add ibus command line tool
  * Improve unit test
  * ibus-daemon now monitors .xml files by default
  * "make check" does not require "make install"
  * Support out-of-tree build
  * pygobject override is added to help migrate from the old python binding.
  * Many bug fixings.
- Switch to dconf from GConf
- Add python bindings
- Add vala bindings
- Drop obsoleted patches:
  * ibus-fix-default-preload-engines.patch
  * ibus-fix-docs-build-error.patch
  * ibus-fix-tray-icon-on-gnome-3.6.patch
  * ibus_indicator-14.patch
- Obsoletes ibus-gnome-shell
- Separate translation files into ibus-lang
- Rename libibus-1_0-0 subpackage to libibus-1_0-5, following
  upstreams soname change.
- Clean up spec file
  * remove special cases for 11.4 and 12.1
* Tue Apr  2 2013 ftake@geeko.jp
- add "Supplements" tag to ibus-gnome-shell
* Thu Mar 28 2013 i@marguerite.su
- fix a typo in Group
- fix python-bytecode-inconsistent-mtime
* Thu Mar 28 2013 jengelh@inai.de
- Put gnome-shell integration files into separate package because
  these (since openSUSE 12.3) pull in a lot of new unwanted packages
  on a GNOME-less system compared to 12.2. (bnc#812298)
- Set versions on BuildRequires according to configure.ac
- Use more robust make install call
- Remove redundant %%clean section
* Sat Feb 16 2013 ftake@geeko.jp
- better solution for bnc#802967
  * add ibus_indicator-14.patch: a shell extension for GNOME 3.6
  * update ibus-fix-tray-icon-on-gnome-3.6.patch
* Sat Feb  9 2013 hillwood@linuxfans.org
- fix bnc#802967
  * fix ibus's tray icon can't show in gnome-shell 3.6 for openSUSE 12.3,
    add ibus-fix-tray-icon-on-gnome-3.6.patch
* Thu Jan 10 2013 ftake@geeko.jp
- add ibus-fix-docs-build-error.patch: to fix build error
  in Factory
* Wed Oct 17 2012 douglarek@outlook.com
-  .spec file optimization
  * remove commented patch lines
  * use `make %%{?_smp_mflags}` instead of `make %%{?jobs:-j%%jobs}`
    see: http://en.opensuse.org/openSUSE:Specfile_guidelines#Parallel_make
* Sat Aug 25 2012 hillwood@linuxfans.org
- update to 1.4.2
  Some bug fixings
* Mon Jun 18 2012 tiwai@suse.de
- Move the strict dependency on libibus-1_0-0 to ibus main package;
  otherwise user may get the inconsistent setups
* Thu May 17 2012 swyear@gmail.com
- remove soft link in RPM_BUILD_ROOT
* Thu May 17 2012 swyear@gmail.com
- mkdir target directory before link
* Thu May 17 2012 swyear@gmail.com
- fix build error in Factory: ln should be done in buildroot
* Wed Mar  7 2012 hillwood@linuxfans.org
- Fix FSF-address warnings in RPMLINT report
* Wed Mar  7 2012 hillwood@linuxfans.org
- Update to 1.4.1
  * Many bug fixings
- Fix several RPMLINT report warnings
* Sun Feb 12 2012 ftake@geeko.jp
- Fix problem default preload engines do not work (bnc#746612)
- Fix slow down issue after "source xim.d/ibus" in a SSH session
* Tue Jan 24 2012 vuntz@opensuse.org
- Split typelib file into typelib-1_0-IBus-1_0 subpackage.
- Add typelib-1_0-IBus-1_0 Requires to devel subpackage.
* Thu Oct 13 2011 tiwai@suse.de
- Add obsoletes for libibus2-32bit in baselibs.conf
* Wed Oct 12 2011 ftake@geeko.jp
- update to 1.4.0
  * Status icon for GNOME 3 (bug#723591)
* Tue Sep  6 2011 ftake@geeko.jp
- Fix xim.d/ibus to launch D-Bus daemon (only for newer D-Bus)
* Mon Aug  8 2011 tiwai@suse.de
- Fix baselibs.conf to update GTK immodule cache properly for
  ibus-gtk-32bit and ibus-gtk3-32bit packages, too
- Clean up spec file
* Mon Jun 27 2011 tiwai@suse.de
- dropped the dependencies with release number
- simplify for passing gtk3 configure option
* Sun Jun 19 2011 swyear@gmail.com
- Change files in package, some should move to devel subpackage and libibus package
* Thu Jun 16 2011 tiwai@suse.de
- Fix xim.d locale directories of ja and ko
- Add xim.d selections for more locales to replace with SCIM
* Wed Jun 15 2011 tiwai@suse.de
- Add provides tag for supported locales (ja, ko, zh)
- Add proper supplements tags to gtk immodule packages
* Mon Jun 13 2011 swyear@gmail.com
- Update to ibus 1.3.9
- Set priority to 40, if we want to use ibus as default input method,
  better use a lower priority, so if any other input method framework
  installed, system can use other input method instead.
- Update README
- Remove kimpanel script from start up script
- Add gtk3 immodule
* Wed Mar  9 2011 tiwai@suse.de
- Fix post scripts to use new gtk2_immodule_* macros (bnc#678080)
* Wed Nov 17 2010 mxwu@novell.com
- Upgrade to ibus 1.3.8:
  * Fix CPU 100%% usage with signal.SIGCHLD
  * Destroy existing connection before creating a new
    connection, and only create the fake context once.
  * Move the candidate window just above the cursor
    when the window and a preedit string overlap.
  * Enable key snooper by default again
  * Always consume the hotkey, even if the hotkey
    associated engine already activated.
  * Fix race condition in bus_ibus_impl_create_engine()
  * Fix a build error of IBus-1.0.gir with gobject-introspection 0.9.6
  * Implement stress tool for ibus.
  * Fix a build error with GTK3 gdkkeysyms.h
  * Add time info in log message from satorux@chromium.org
  * Fix memory leak in ibus_input_context_process_key_event by Fujiwarat
  * Fix segv in bus_engine_proxy_process_key_event_reply_cb
  * Fix property issue.
  * Updated many translations.
* Tue Jul 13 2010 mxwu@novell.com
- Add ibus-disable-portability-check.patch
  * Disable automake's portability check, make OBS happy.
* Mon Jul 12 2010 mxwu@novell.com
- Upgrade to 1.3.6:
  * Support gtk3
  * Support gobject-introspection
  * Support vala language
  * Fix some bugs
* Tue May 11 2010 mxwu@novell.com
- Upgrade to 1.3.3:
  * Add configure option to disable key snooper in gtk im context
  * Fix a crash in ibus-x11
  * Fix a crash in ibus-daemon
  * For show language bar option, use {Embedded in menu} to replace {Never}.
  * Update some translation files
  * Fix crash if ibus loads engine.xml failed
  * Fix focus problems
  * Does not hard code iso-codes location
  * Fix link problem with binutils-gold
  * Updated translations
  * Optimize database query method for better performance
  * Many bug fixing
  * use floating IBusObject
  * support share one global engine in all applications
  * some ui improvements
  * many bug fixing
* Fri Mar 26 2010 tiwai@suse.de
- move post scriptlets to install
* Wed Mar 24 2010 tiwai@suse.de
- Split libibus1 subpackage
- Misc clean-ups in spec file, avoid unnecessary workarounds
* Thu Jan 28 2010 mxwu@novell.com
- Add ibus-python-install-dir.patch
  - Fix the installing path on X86_64
* Thu Jan 28 2010 mxwu@novell.com
- Initial import
